/*
 * Copyright (C) 2013  Joakim Soderlund
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


package vispaca.data;

import java.util.Objects;


/**
 * Simple data table.
 */
public class DataTable {

	private Class<?>[] attributeTypes;
	private String[] attributeNames;

	private DataElement[] elements;


	public DataTable(Class<?>[] attributeTypes, String[] attributeNames, DataElement[] elements) {
		Objects.requireNonNull(attributeTypes);
		Objects.requireNonNull(attributeNames);
		Objects.requireNonNull(elements);

		int attributeCount = attributeTypes.length;

		if (attributeCount != attributeNames.length) {
			throw new IllegalArgumentException("Attribute type and name arrays must be of the same length.");
		}

		for (DataElement element : elements) {
			if (attributeCount != element.getAttributeCount()) {
				throw new IllegalArgumentException("Attribute type and element arrays must be of the same length.");
			}
		}

		this.attributeTypes = attributeTypes;
		this.attributeNames = attributeNames;
		this.elements = elements;
	}


	/**
	 * @return The number of attributes in the table.
	 */
	public int getAttributeCount() {
		return attributeTypes.length;
	}


	/**
	 * @param attribute The attribute to retrieve.
	 * @return The type of the attribute.
	 */
	public Class<?> getAttributeType(int attribute) {
		return attributeTypes[attribute];
	}


	/**
	 * @param attribute The attribute to retrieve.
	 * @return The name of the attribute.
	 */
	public String getAttributeName(int attribute) {
		return attributeNames[attribute];
	}


	/**
	 * @return The number of rows in the table.
	 */
	public int getElementCount() {
		return elements.length;
	}


	/**
	 * @param row The row to retrieve.
	 * @return The element of the row.
	 */
	public DataElement getElement(int row) {
		return elements[row];
	}
}
