/*
 * Copyright (C) 2013  Joakim Soderlund
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


package vispaca.event;

import java.util.HashSet;
import java.util.Objects;
import java.util.Set;


/**
 * Provides support for emitting update events.
 */
public class UpdateMixin implements UpdateEmitter {

	Set<UpdateListener> listeners = new HashSet<>();


	@Override
	public boolean addUpdateListener(UpdateListener listener) {
		Objects.requireNonNull(listener);
		return listeners.add(listener);
	}


	@Override
	public boolean removeUpdateListener(UpdateListener listener) {
		return listeners.remove(listener);
	}


	@Override
	public UpdateListener[] getUpdateListeners() {
		return listeners.toArray(new UpdateListener[] {});
	}


	public void fireUpdateListeners() {
		for (UpdateListener listener : listeners) {
			listener.updatePerformed();
		}
	}
}
