/*
 * Copyright (C) 2013  Joakim Soderlund
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


package vispaca.gui;

import java.awt.BorderLayout;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.util.Objects;

import javax.swing.JPanel;

import vispaca.data.DataManager;
import vispaca.data.DataTable;
import vispaca.misc.PanelUtil;


/**
 * Contains all filter panels.
 */
public class VFilterPanel extends JPanel {

	private static final long serialVersionUID = 3972577441701603583L;

	private GridBagConstraints constraints = PanelUtil.getVerticalConstraints();
	private JPanel wrapperPanel = new JPanel();


	public VFilterPanel() {
		setLayout(new BorderLayout());
		wrapperPanel.setLayout(new GridBagLayout());
		add(wrapperPanel, BorderLayout.CENTER);
	}


	/**
	 * @param dataManager The data manager to use.
	 */
	public void setDataManager(DataManager dataManager) {
		Objects.requireNonNull(dataManager);

		DataTable dataTable = dataManager.getDataTable();
		int attributeCount = dataTable.getAttributeCount();

		wrapperPanel.removeAll();

		for (int i = 0; i < attributeCount; i++) {
			Class<?> type = dataTable.getAttributeType(i);

			if (Number.class.isAssignableFrom(type)) {
				wrapperPanel.add(new VNumberFilterPanel(dataManager, i), constraints);
			}
		}
	}
}
