/*
 * Copyright (C) 2013  Joakim Soderlund
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


package vispaca.gui;

import java.awt.Dimension;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.util.Objects;

import javax.swing.JFrame;

import vispaca.data.DataManager;
import vispaca.event.DestroyListener;


/**
 * A frame for visualizations which handles destroy events properly.
 */
public class VFrame extends JFrame implements DestroyListener {

	private static final long serialVersionUID = 1872541588767247867L;

	private DataManager dataManager;
	private VPanel vPanel;


	public VFrame(DataManager dataManager) {
		Objects.requireNonNull(dataManager);

		this.dataManager = dataManager;

		dataManager.addDestroyListener(this);
		addWindowFocusListener(new MyWindowListener());
	}


	/**
	 * Sets the panel which the frame should contain.
	 */
	public void setVPanel(VPanel vPanel) {
		Objects.requireNonNull(vPanel);

		this.vPanel = vPanel;

		vPanel.setPreferredSize(new Dimension(640, 480));
		setContentPane(vPanel);
		pack();
	}


	@Override
	public void destroyPerformed() {
		dataManager.removeDestroyListener(this);

		if (vPanel != null) {
			vPanel.destroyPerformed();
		}

		dispose();
	}


	/**
	 * Handles attempts to close the window.
	 */
	private class MyWindowListener extends WindowAdapter {
		@Override
		public void windowClosing(WindowEvent e) {
			destroyPerformed();
		}
	}
}
