/*
 * Copyright (C) 2013  Joakim Soderlund
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


package vispaca.gui;

import java.awt.BorderLayout;
import java.awt.Frame;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.Objects;

import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JPanel;

import vispaca.data.DataManager;
import vispaca.data.DataTable;
import vispaca.misc.ParallelConfig;
import vispaca.misc.PanelUtil;


/**
 * Contains all config panels for the scatter panel.
 */
public class VParallelConfigDialog extends JDialog {

	private static final long serialVersionUID = 3972577441701603583L;

	private ParallelConfig config;
	private DataTable dataTable;

	private VAttributeSelectionPanel attributeSelectionPanel;

	public VParallelConfigDialog(Frame frame, DataManager dataManager, ParallelConfig config) {
		super(frame);

		Objects.requireNonNull(dataManager);
		Objects.requireNonNull(config);

		this.config = config;
		this.dataTable = dataManager.getDataTable();

		GridBagConstraints constraints = PanelUtil.getVerticalConstraints();
		JPanel wrapperPanel = new JPanel();

		wrapperPanel.setLayout(new GridBagLayout());

		setLayout(new BorderLayout());
		setModal(true);
		setDefaultCloseOperation(JDialog.DISPOSE_ON_CLOSE);

		attributeSelectionPanel = new VAttributeSelectionPanel(dataTable, config);

		wrapperPanel.add(attributeSelectionPanel, constraints);
		wrapperPanel.add(new VNumberConfigPanel(dataManager, config.getColor(), "Color"), constraints);

		JButton closeButton = new JButton("Close");
		closeButton.addActionListener(new CloseButtonListener());

		add(wrapperPanel, BorderLayout.CENTER);
		add(closeButton, BorderLayout.SOUTH);

		setTitle("VisPaca - Parallel - Config");
		setSize(480, 320);
		setLocationRelativeTo(frame);
	}


	@Override
	public void dispose() {
		config.init(dataTable, attributeSelectionPanel.getAttributes());
		super.dispose();
	}


	/**
	 * Closes the dialog when the close button is clicked.
	 */
	public class CloseButtonListener implements ActionListener {
		@Override
		public void actionPerformed(ActionEvent e) {
			dispose();
		}
	}
}
