/*
 * Copyright (C) 2013  Joakim Soderlund
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


package vispaca.misc;

import java.util.Objects;

import vispaca.data.DataElement;
import vispaca.data.DataTable;


/**
 * Configuration for a single attribute.
 */
public class AttributeConfig {

	private int attribute = -1;
	private double currentMin = 0;
	private double currentMax = 1;
	private double initialMin = 0;
	private double initialMax = 1;


	public AttributeConfig() {

	}


	public AttributeConfig(DataTable dataTable, int attribute) {
		init(dataTable, attribute);
	}


	/**
	 * Sets attribute defaults.
	 */
	public void init(DataTable dataTable, int attribute) {
		Objects.requireNonNull(dataTable);

		if (attribute < 0) {
			this.attribute = -1;
			initialMin = 0;
			initialMax = 1;
			currentMin = 0;
			currentMax = 1;
			return;
		}

		if (!Number.class.isAssignableFrom(dataTable.getAttributeType(attribute))) {
			throw new IllegalArgumentException("Attribute type must be of numbers.");
		}

		this.attribute = attribute;
		initialMin = Double.MAX_VALUE;
		initialMax = Double.MIN_VALUE;

		int elementCount = dataTable.getElementCount();

		for (int i = 0; i < elementCount; i++) {
			DataElement element = dataTable.getElement(i);
			double value = element.getDouble(attribute);

			if (value < initialMin) {
				initialMin = value;
			}

			if (initialMax < value) {
				initialMax = value;
			}
		}

		currentMin = initialMin;
		currentMax = initialMax;
	}


	public int getAttribute() {
		return attribute;
	}


	public void setAttribute(int attribute) {
		this.attribute = attribute;
	}


	public double getCurrentMin() {
		return currentMin;
	}


	public void setCurrentMin(double currentMin) {
		this.currentMin = currentMin;
	}


	public double getCurrentMax() {
		return currentMax;
	}


	public void setCurrentMax(double currentMax) {
		this.currentMax = currentMax;
	}


	public double getInitialMin() {
		return initialMin;
	}


	public void setInitialMin(double initialMin) {
		this.initialMin = initialMin;
	}


	public double getInitialMax() {
		return initialMax;
	}


	public void setInitialMax(double initialMax) {
		this.initialMax = initialMax;
	}
}
