/*
 * Copyright (C) 2013  Joakim Soderlund
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


package vispaca.misc;

import java.awt.Color;
import java.util.Collection;

import vispaca.data.DataElement;
import vispaca.data.DataManager;


/**
 * Define colors for the visualizations to use.
 */
public class ColorDefiner {

	public static final Color BACKGROUND = Color.WHITE;
	public static final Color NEUTRAL = Color.BLACK;
	public static final Color TOUCHED = new Color(1.0f, 0.33f, 0.33f);
	public static final Color HIGHLIGHTED = new Color(0.0f, 0.9f, 0.0f);


	/**
	 * @param ratio Value between 0 and 1.
	 * @return The color for the desired ratio.
	 */
	public static Color range(float ratio) {
		if (ratio < 0 || 1 < ratio) {
			throw new IllegalArgumentException("Ratio must be between 0 and 1.");
		}

		return new Color(ratio, ratio, 1.0f - ratio);
	}


	/**
	 * @return Color based on the input elements.
	 */
	public static Color get(DataManager dataManager, CoordinateMapper mapper, AttributeConfig config, Collection<DataElement> elements) {
		Color color = NEUTRAL;
		int attribute = config.getAttribute();

		if (elements.isEmpty()) {
			return color;
		}

		if (0 <= attribute) {
			double colorRatio = 0;

			for (DataElement element : elements) {
				colorRatio += element.getDouble(attribute);
			}

			colorRatio /= elements.size();

			color = ColorDefiner.range((float) mapper.toPixel(colorRatio));
		}

		for (DataElement element : elements) {
			if (dataManager.isHighlighted(element)) {
				color = HIGHLIGHTED;
				break;

			} else if (dataManager.isTouched(element)) {
				color = TOUCHED;
			}
		}

		return color;
	}
}
