/*
 * Copyright (C) 2013  Joakim Soderlund
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


package vispaca.misc;

import java.util.Collection;
import java.util.Objects;

import vispaca.data.DataElement;
import vispaca.data.DataTable;


/**
 * Various utilities for DataElement.
 */
public class DataElementUtil {

	/**
	 * @return HTML table of elements.
	 */
	public static String getElementTable(DataTable dataTable, Collection<DataElement> elements) {
		if (elements == null || elements.isEmpty()) {
			return null;
		}

		Objects.requireNonNull(dataTable);

		int attributeCount = dataTable.getAttributeCount();
		StringBuilder builder = new StringBuilder();

		builder.append("<html><table><tr>");

		for (DataElement element : elements) {
			builder.append("<td>");

			for (int i = 0; i < attributeCount; i++) {
				String name = dataTable.getAttributeName(i);
				String value = element.getString(i);

				builder.append("<b>");
				builder.append(name);
				builder.append("</b>: ");
				builder.append(value);
				builder.append("<br />");
			}

			builder.append("</td>");
		}

		builder.append("</tr></table></html>");

		return builder.toString();
	}
}
