/*
 * Copyright (C) 2013  Joakim Soderlund
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


package vispaca.misc;

import java.awt.FontMetrics;
import java.awt.Graphics;
import java.awt.Rectangle;
import java.awt.geom.Rectangle2D;
import java.util.Objects;

import vispaca.data.DataTable;


/**
 * Draws rules in Swing for coordinate systems in 2D.
 */
public class ParallelRulerUtil {

	private Graphics g;
	private Rectangle size;
	private DataTable dataTable;
	private ParallelConfig config;
	private CoordinateMapper xMapper;

	private FontMetrics fontMetrics;


	public ParallelRulerUtil() {

	}


	public ParallelRulerUtil(Graphics g, Rectangle size, DataTable dataTable, ParallelConfig config, CoordinateMapper xMapper) {
		init(g, size, dataTable, config, xMapper);
	}


	/**
	 * For initialization or reuse of objects.
	 */
	public void init(Graphics g, Rectangle size, DataTable dataTable, ParallelConfig config, CoordinateMapper xMapper) {
		Objects.requireNonNull(g);
		Objects.requireNonNull(size);
		Objects.requireNonNull(dataTable);
		Objects.requireNonNull(config);
		Objects.requireNonNull(xMapper);

		this.g = g;
		this.size = size;
		this.dataTable = dataTable;
		this.config = config;
		this.xMapper = xMapper;

		fontMetrics = g.getFontMetrics();

		int rulerHeight = fontMetrics.getHeight() * 2;

		size.setSize(size.width, size.height - rulerHeight - 1);
	}


	/**
	 * Draw the rulers.
	 */
	public void drawRulers() {
		g.setColor(ColorDefiner.NEUTRAL);

		int axisCount = config.getAxisCount();

		for (int i = 0; i < axisCount; i++) {
			drawRulerTextX(i);
		}
	}


	/**
	 * Draw the ruler for a value on the X axis.
	 */
	public void drawRulerTextX(int index) {
		AttributeConfig axisConfig = config.getAxis(index);
		int attribute = axisConfig.getAttribute();

		String text = dataTable.getAttributeName(attribute);
		Rectangle2D aText = fontMetrics.getStringBounds(text, g);

		int xCenter = (int) Math.round(xMapper.toPixel(index));
		int yBottom = size.height + 1;

		int xText = xCenter - (int) (aText.getWidth() / 2);
		int yText;

		if (index % 2 == 0) {
			yText = yBottom + 2 + (int) aText.getHeight();
		} else {
			yText = yBottom + 4 + ((int) aText.getHeight() * 2);
		}

		if (size.width <= aText.getWidth() + xCenter) {
			xText = size.width - (int) aText.getWidth() - 2;
		} else if (xText <= size.x) {
			xText = size.x + 1;
		}

		g.drawLine(xCenter, size.y, xCenter, size.height);
		g.drawString(text, xText, yText);
	}
}
