/*
 * Copyright (C) 2013  Joakim Soderlund
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


package vispaca.data;

import static junit.framework.Assert.assertEquals;

import java.io.ByteArrayInputStream;

import org.junit.Before;
import org.junit.Test;


public class DataParserTest {

	DataTable dataTable;

	final String csv =
			"\"string\", \"int\"  ,  \"double\"\n\n" +
			"\"a\",1,1.1\n" +
			"\"b\", 2, 2.2\n\n\n" +
			"\"c\"  ,  3  ,  3.3\n";

	final Class<?>[] eAttributeTypes = new Class<?>[] {String.class, Integer.class, Double.class};
	final String[] eAttributeNames = new String[] {"string", "int", "double"};
	final DataElement[] eElements = new DataElement[] {
			new DataElement(new String[] {"a", "1", "1.1"}),
			new DataElement(new String[] {"b", "2", "2.2"}),
			new DataElement(new String[] {"c", "3", "3.3"}),
	};


	@Before
	public void setUp() {
		ByteArrayInputStream stream = new ByteArrayInputStream(csv.getBytes());
		dataTable = DataParser.parse(stream);
	}


	@Test
	public void testGetAttributeType() {
		assertEquals(eAttributeTypes.length, dataTable.getAttributeCount());

		for (int i = 0; i < eAttributeTypes.length; i++) {
			assertEquals(eAttributeTypes[i], dataTable.getAttributeType(i));
		}
	}


	@Test
	public void testGetAttributeName() {
		assertEquals(eAttributeNames.length, dataTable.getAttributeCount());

		for (int i = 0; i < eAttributeNames.length; i++) {
			assertEquals(eAttributeNames[i], dataTable.getAttributeName(i));
		}
	}


	@Test
	public void testGetElement() {
		assertEquals(eElements.length, dataTable.getElementCount());
		assertEquals(eAttributeTypes.length, dataTable.getAttributeCount());

		for (int i = 0; i < eElements.length; i++) {
			DataElement eElement = eElements[i];
			DataElement element = dataTable.getElement(i);

			for (int j = 0; j < eAttributeTypes.length; j++) {
				assertEquals(eElement.getString(j), element.getString(j));
			}
		}
	}
}
